# Lace codebook

Contains the lace codebook specification as well as utilities for generating
defaults.

If you design a new type, implement `FromStr` in `lace_utils`, and decide its
precident for the codebook in  this crate.
